@@ -1,6 +1,6 @@
 package Map::Tube::Utils;
 
-$Map::Tube::Utils::VERSION   = '3.37';
+$Map::Tube::Utils::VERSION   = '3.38';
 $Map::Tube::Utils::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Map::Tube::Utils - Helper package for Map::Tube.
 
 =head1 VERSION
 
-Version 3.37
+Version 3.38
 
 =cut
 
@@ -42,7 +42,7 @@ sub to_perl {
         $text;
     };
 
-    return JSON->new->utf8(1)->decode($json_text);
+    return JSON->new->allow_nonref->utf8(1)->decode($json_text);
 }
 
 sub trim {
